```{eval-rst}
.. python-renameat2 documentation master file, created by
   sphinx-quickstart on Sat Apr 17 13:21:38 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
```

```{include} ../README.md
```

```{eval-rst}
.. toctree::
   :maxdepth: 1

   examples.md
   renameat2.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
```
